@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths for the programming examples
-%  Last updated on December 17, 2019
+%  Last updated on February 27, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
@@ -35,6 +35,7 @@ logtalk_library_path(examples, logtalk_user('examples/')).
 logtalk_library_path(ack, examples('ack/')).
 logtalk_library_path(adventure, examples('adventure/')).
 logtalk_library_path(aliases, examples('aliases/')).
+logtalk_library_path(around_methods, examples('around_methods/')).
 logtalk_library_path(assign_parameters, examples('assign_parameters/')).
 logtalk_library_path(assumptions, examples('assumptions/')).
 logtalk_library_path(attvars, examples('attvars/')).
@@ -57,6 +58,7 @@ logtalk_library_path(cc, examples('cc/')).
 logtalk_library_path(checkpoint, threads('checkpoint/')).
 logtalk_library_path(classmethods, examples('classmethods/')).
 logtalk_library_path(classvars, examples('classvars/')).
+logtalk_library_path(closed_world_assumption, examples('closed_world_assumption/')).
 logtalk_library_path(clp_bp, constraints('bp/')).
 logtalk_library_path(clp_eclipse, constraints('eclipse/')).
 logtalk_library_path(clp_gprolog, constraints('gprolog/')).
@@ -132,12 +134,14 @@ logtalk_library_path(my_types, examples('my_types/')).
 logtalk_library_path(named_databases, examples('named_databases/')).
 logtalk_library_path(nondet, threads('nondet/')).
 logtalk_library_path(now_you_see_me, examples('now_you_see_me/')).
+logtalk_library_path(object_aliases, examples('object_aliases/')).
 logtalk_library_path(operators, examples('operators/')).
 logtalk_library_path(patches, examples('patches/')).
 logtalk_library_path(patching, examples('patching/')).
 logtalk_library_path(parametric, examples('parametric/')).
 logtalk_library_path(pardicts, examples('pardicts/')).
 logtalk_library_path(parvars, examples('parvars/')).
+logtalk_library_path(pengines, examples('pengines/')).
 logtalk_library_path(people, examples('people/')).
 logtalk_library_path(persistency, examples('persistency/')).
 logtalk_library_path(philosophers, threads('philosophers/')).
@@ -147,6 +151,7 @@ logtalk_library_path(pmq, engines('pmq/')).
 logtalk_library_path(poem, examples('poem/')).
 logtalk_library_path(points, examples('points/')).
 logtalk_library_path(polygons, examples('polygons/')).
+logtalk_library_path(predicate_lookups, examples('predicate_lookups/')).
 logtalk_library_path(primes, threads('primes/')).
 logtalk_library_path(profiling, examples('profiling/')).
 logtalk_library_path(prototypes, examples('prototypes/')).
@@ -163,6 +168,7 @@ logtalk_library_path(scopes, examples('scopes/')).
 logtalk_library_path(searching, examples('searching/')).
 logtalk_library_path(securemp, examples('securemp/')).
 logtalk_library_path(self_messages, examples('self_messages/')).
+logtalk_library_path(self_vs_this, examples('self_vs_this/')).
 logtalk_library_path(serialization, examples('serialization/')).
 logtalk_library_path(shapes_ch, examples('shapes/ch/')).
 logtalk_library_path(shapes_ph, examples('shapes/ph/')).
